dexter has submitted this change. ( 
https://gerrit.osmocom.org/c/android-apdu-proxy/+/38857?usp=email )

Change subject: MainActivity: use the API level to check the Android release 
version
......................................................................

MainActivity: use the API level to check the Android release version

Change-Id: I2e8a22a638a3c9033002cfa61e1179f8a8d547df
Related: OS#6367
---
M app/src/main/java/org/osmocom/androidApduProxy/MainActivity.java
1 file changed, 2 insertions(+), 2 deletions(-)

Approvals:
  osmith: Looks good to me, approved
  Jenkins Builder: Verified
  laforge: Looks good to me, approved




diff --git a/app/src/main/java/org/osmocom/androidApduProxy/MainActivity.java 
b/app/src/main/java/org/osmocom/androidApduProxy/MainActivity.java
index e0174e6..2585663 100644
--- a/app/src/main/java/org/osmocom/androidApduProxy/MainActivity.java
+++ b/app/src/main/java/org/osmocom/androidApduProxy/MainActivity.java
@@ -162,9 +162,9 @@

         //Check if this device even supports APDU access to an UICC/eUICC 
card, if not we display
         //an error message and continue normally, maybe we are lucky and it 
works anyway.
         //(This check only works on Android 11 and higher,
         //see also 
https://developer.android.com/develop/connectivity/telecom/dialer-app/telephony-ids)
-        if (Double.valueOf(Build.VERSION.RELEASE) >= 11 &&
+        if (Build.VERSION.SDK_INT >= 30 &&
                 
!packageManager.hasSystemFeature(PackageManager.FEATURE_SE_OMAPI_UICC)) {
             msgBox("Feature FEATURE_SE_OMAPI_UICC is not available on this 
@@ -162,9 +162,9 @@
         //an error message and continue normally, maybe we are lucky and it 
works anyway.
-        //(This check only works on Android 11 and higher,
+        //(This check only works on Android 11 / API-level 30 and higher,
         //see also 
https://developer.android.com/develop/connectivity/telecom/dialer-app/telephony-ids)
device, APDU access to UICC/eUICC not possible!",
                     "Error");

--
To view, visit https://gerrit.osmocom.org/c/android-apdu-proxy/+/38857?usp=email
To unsubscribe, or for help writing mail filters, visit 
https://gerrit.osmocom.org/settings?usp=email

Gerrit-MessageType: merged
Gerrit-Project: android-apdu-proxy
Gerrit-Branch: master
Gerrit-Change-Id: I2e8a22a638a3c9033002cfa61e1179f8a8d547df
Gerrit-Change-Number: 38857
Gerrit-PatchSet: 1
Gerrit-Owner: dexter <[email protected]>
Gerrit-Reviewer: Jenkins Builder
Gerrit-Reviewer: dexter <[email protected]>
Gerrit-Reviewer: laforge <[email protected]>
Gerrit-Reviewer: osmith <[email protected]>

Reply via email to